@@ -21,11 +21,11 @@ class BaseAuthFileServerConnector(FileServerConnector):
     Config = FileServerConnector.Config
 
     def __init__(self, config: Config, context: Context) -> None:
-        self._server_name = config.server_name
         super(BaseAuthFileServerConnector, self).__init__(config, context)
+        self._project_name = context.project_name
 
     def _construct_headers(self) -> dict[str, str]:
         headers = super(BaseAuthFileServerConnector, self)._construct_headers()
-        headers["server_name"] = self._context.project_name
+        headers["server_name"] = self._project_name
         return headers
 
